# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: experiment_collection_core/service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='experiment_collection_core/service.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\032experiment_collection_core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(experiment_collection_core/service.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"e\n\nExperiment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06params\x18\x03 \x01(\t\x12\x0f\n\x07metrics\x18\x04 \x01(\t\"H\n\x10SimpleExperiment\x12\r\n\x05token\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x12\n\nexperiment\x18\x03 \x01(\t\"3\n\x0fSimpleNamespace\x12\r\n\x05token\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"\x1c\n\x0bSimpleToken\x12\r\n\x05token\x18\x01 \x01(\t\",\n\x0bSimpleReply\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"R\n\rAddExperiment\x12\r\n\x05token\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x1f\n\nexperiment\x18\x03 \x01(\x0b\x32\x0b.Experiment\"S\n\x10\x45xperimentsReply\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12 \n\x0b\x65xperiments\x18\x03 \x03(\x0b\x32\x0b.Experiment\"K\n\x12GrantAccessRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x13\n\x0bother_token\x18\x03 \x01(\t\"b\n\x18ReserveExperimentRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x12\n\nexperiment\x18\x03 \x01(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\r2\xc3\x03\n\x11\x45xperimentService\x12\x32\n\x10\x43reateExperiment\x12\x0e.AddExperiment\x1a\x0c.SimpleReply\"\x00\x12>\n\x11ReserveExperiment\x12\x19.ReserveExperimentRequest\x1a\x0c.SimpleReply\"\x00\x12\x35\n\x10\x44\x65leteExperiment\x12\x11.SimpleExperiment\x1a\x0c.SimpleReply\"\x00\x12\x34\n\x0f\x43heckExperiment\x12\x11.SimpleExperiment\x1a\x0c.SimpleReply\"\x00\x12\x37\n\x0eGetExperiments\x12\x10.SimpleNamespace\x1a\x11.ExperimentsReply\"\x00\x12\x33\n\x0f\x43reateNamespace\x12\x10.SimpleNamespace\x1a\x0c.SimpleReply\"\x00\x12+\n\x0bRevokeToken\x12\x0c.SimpleToken\x1a\x0c.SimpleReply\"\x00\x12\x32\n\x0bGrantAccess\x12\x13.GrantAccessRequest\x1a\x0c.SimpleReply\"\x00\x42\x1c\n\x1a\x65xperiment_collection_coreb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_EXPERIMENT = _descriptor.Descriptor(
  name='Experiment',
  full_name='Experiment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Experiment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='Experiment.time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='Experiment.params', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='Experiment.metrics', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=178,
)


_SIMPLEEXPERIMENT = _descriptor.Descriptor(
  name='SimpleExperiment',
  full_name='SimpleExperiment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='SimpleExperiment.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='SimpleExperiment.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experiment', full_name='SimpleExperiment.experiment', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=252,
)


_SIMPLENAMESPACE = _descriptor.Descriptor(
  name='SimpleNamespace',
  full_name='SimpleNamespace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='SimpleNamespace.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='SimpleNamespace.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=305,
)


_SIMPLETOKEN = _descriptor.Descriptor(
  name='SimpleToken',
  full_name='SimpleToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='SimpleToken.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=307,
  serialized_end=335,
)


_SIMPLEREPLY = _descriptor.Descriptor(
  name='SimpleReply',
  full_name='SimpleReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='SimpleReply.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='SimpleReply.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=381,
)


_ADDEXPERIMENT = _descriptor.Descriptor(
  name='AddExperiment',
  full_name='AddExperiment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='AddExperiment.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='AddExperiment.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experiment', full_name='AddExperiment.experiment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=465,
)


_EXPERIMENTSREPLY = _descriptor.Descriptor(
  name='ExperimentsReply',
  full_name='ExperimentsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ExperimentsReply.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='ExperimentsReply.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experiments', full_name='ExperimentsReply.experiments', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=550,
)


_GRANTACCESSREQUEST = _descriptor.Descriptor(
  name='GrantAccessRequest',
  full_name='GrantAccessRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='GrantAccessRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='GrantAccessRequest.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_token', full_name='GrantAccessRequest.other_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=627,
)


_RESERVEEXPERIMENTREQUEST = _descriptor.Descriptor(
  name='ReserveExperimentRequest',
  full_name='ReserveExperimentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='ReserveExperimentRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='ReserveExperimentRequest.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experiment', full_name='ReserveExperimentRequest.experiment', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='ReserveExperimentRequest.duration', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=727,
)

_EXPERIMENT.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ADDEXPERIMENT.fields_by_name['experiment'].message_type = _EXPERIMENT
_EXPERIMENTSREPLY.fields_by_name['experiments'].message_type = _EXPERIMENT
DESCRIPTOR.message_types_by_name['Experiment'] = _EXPERIMENT
DESCRIPTOR.message_types_by_name['SimpleExperiment'] = _SIMPLEEXPERIMENT
DESCRIPTOR.message_types_by_name['SimpleNamespace'] = _SIMPLENAMESPACE
DESCRIPTOR.message_types_by_name['SimpleToken'] = _SIMPLETOKEN
DESCRIPTOR.message_types_by_name['SimpleReply'] = _SIMPLEREPLY
DESCRIPTOR.message_types_by_name['AddExperiment'] = _ADDEXPERIMENT
DESCRIPTOR.message_types_by_name['ExperimentsReply'] = _EXPERIMENTSREPLY
DESCRIPTOR.message_types_by_name['GrantAccessRequest'] = _GRANTACCESSREQUEST
DESCRIPTOR.message_types_by_name['ReserveExperimentRequest'] = _RESERVEEXPERIMENTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Experiment = _reflection.GeneratedProtocolMessageType('Experiment', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENT,
  '__module__' : 'experiment_collection_core.service_pb2'
  # @@protoc_insertion_point(class_scope:Experiment)
  })
_sym_db.RegisterMessage(Experiment)

SimpleExperiment = _reflection.GeneratedProtocolMessageType('SimpleExperiment', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEEXPERIMENT,
  '__module__' : 'experiment_collection_core.service_pb2'
  # @@protoc_insertion_point(class_scope:SimpleExperiment)
  })
_sym_db.RegisterMessage(SimpleExperiment)

SimpleNamespace = _reflection.GeneratedProtocolMessageType('SimpleNamespace', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLENAMESPACE,
  '__module__' : 'experiment_collection_core.service_pb2'
  # @@protoc_insertion_point(class_scope:SimpleNamespace)
  })
_sym_db.RegisterMessage(SimpleNamespace)

SimpleToken = _reflection.GeneratedProtocolMessageType('SimpleToken', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLETOKEN,
  '__module__' : 'experiment_collection_core.service_pb2'
  # @@protoc_insertion_point(class_scope:SimpleToken)
  })
_sym_db.RegisterMessage(SimpleToken)

SimpleReply = _reflection.GeneratedProtocolMessageType('SimpleReply', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEREPLY,
  '__module__' : 'experiment_collection_core.service_pb2'
  # @@protoc_insertion_point(class_scope:SimpleReply)
  })
_sym_db.RegisterMessage(SimpleReply)

AddExperiment = _reflection.GeneratedProtocolMessageType('AddExperiment', (_message.Message,), {
  'DESCRIPTOR' : _ADDEXPERIMENT,
  '__module__' : 'experiment_collection_core.service_pb2'
  # @@protoc_insertion_point(class_scope:AddExperiment)
  })
_sym_db.RegisterMessage(AddExperiment)

ExperimentsReply = _reflection.GeneratedProtocolMessageType('ExperimentsReply', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTSREPLY,
  '__module__' : 'experiment_collection_core.service_pb2'
  # @@protoc_insertion_point(class_scope:ExperimentsReply)
  })
_sym_db.RegisterMessage(ExperimentsReply)

GrantAccessRequest = _reflection.GeneratedProtocolMessageType('GrantAccessRequest', (_message.Message,), {
  'DESCRIPTOR' : _GRANTACCESSREQUEST,
  '__module__' : 'experiment_collection_core.service_pb2'
  # @@protoc_insertion_point(class_scope:GrantAccessRequest)
  })
_sym_db.RegisterMessage(GrantAccessRequest)

ReserveExperimentRequest = _reflection.GeneratedProtocolMessageType('ReserveExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESERVEEXPERIMENTREQUEST,
  '__module__' : 'experiment_collection_core.service_pb2'
  # @@protoc_insertion_point(class_scope:ReserveExperimentRequest)
  })
_sym_db.RegisterMessage(ReserveExperimentRequest)


DESCRIPTOR._options = None

_EXPERIMENTSERVICE = _descriptor.ServiceDescriptor(
  name='ExperimentService',
  full_name='ExperimentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=730,
  serialized_end=1181,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateExperiment',
    full_name='ExperimentService.CreateExperiment',
    index=0,
    containing_service=None,
    input_type=_ADDEXPERIMENT,
    output_type=_SIMPLEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReserveExperiment',
    full_name='ExperimentService.ReserveExperiment',
    index=1,
    containing_service=None,
    input_type=_RESERVEEXPERIMENTREQUEST,
    output_type=_SIMPLEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteExperiment',
    full_name='ExperimentService.DeleteExperiment',
    index=2,
    containing_service=None,
    input_type=_SIMPLEEXPERIMENT,
    output_type=_SIMPLEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CheckExperiment',
    full_name='ExperimentService.CheckExperiment',
    index=3,
    containing_service=None,
    input_type=_SIMPLEEXPERIMENT,
    output_type=_SIMPLEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExperiments',
    full_name='ExperimentService.GetExperiments',
    index=4,
    containing_service=None,
    input_type=_SIMPLENAMESPACE,
    output_type=_EXPERIMENTSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNamespace',
    full_name='ExperimentService.CreateNamespace',
    index=5,
    containing_service=None,
    input_type=_SIMPLENAMESPACE,
    output_type=_SIMPLEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeToken',
    full_name='ExperimentService.RevokeToken',
    index=6,
    containing_service=None,
    input_type=_SIMPLETOKEN,
    output_type=_SIMPLEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GrantAccess',
    full_name='ExperimentService.GrantAccess',
    index=7,
    containing_service=None,
    input_type=_GRANTACCESSREQUEST,
    output_type=_SIMPLEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXPERIMENTSERVICE)

DESCRIPTOR.services_by_name['ExperimentService'] = _EXPERIMENTSERVICE

# @@protoc_insertion_point(module_scope)



import abc
import typing

from .experiment import Experiment


class ExperimentCollectionABC(metaclass=abc.ABCMeta):

    @abc.abstractmethod
    def close(self):
        pass

    @abc.abstractmethod
    def add_experiment(self, exp: Experiment, *, ignore_included=False):
        pass

    @abc.abstractmethod
    def reserve_experiment(self, exp: typing.Union[Experiment, str], duration: int) -> bool:
        pass

    @abc.abstractmethod
    def delete_experiment(self, exp: typing.Union[Experiment, str]):
        pass

    @abc.abstractmethod
    def check_experiment(self, exp: typing.Union[Experiment, str]) -> bool:
        pass

    @abc.abstractmethod
    def get_experiments(self, normalize=True):
        pass

    @abc.abstractmethod
    def create_namespace(self, name: str):
        pass

    @abc.abstractmethod
    def revoke(self, *, force=False):
        pass

    @abc.abstractmethod
    def grant(self, token: str):
        pass
